@@ -12,6 +12,7 @@ from django.utils.translation import gettext as _
 
 from link_all.models import LinkAllPluginModel
 from link_all.models import LinkButtonPluginModel
+from link_all.settings import LINK_ALL_ENABLE_BUTTON_PLUGIN
 
 
 logger = logging.getLogger(__name__)
@@ -74,7 +75,6 @@ class LinkAllPlugin(CMSPluginBase):
         return super().changeform_view(request, object_id, form_url, extra_context)
 
 
-@plugin_pool.register_plugin
 class LinkButtonPlugin(LinkAllPlugin):
     name = _("Link / Button")
     model = LinkButtonPluginModel
@@ -100,3 +100,9 @@ class LinkButtonPlugin(LinkAllPlugin):
             ],
         }),
     ]
+
+
+if LINK_ALL_ENABLE_BUTTON_PLUGIN:
+    plugin_pool.register_plugin(LinkButtonPlugin)
+else:
+    plugin_pool.register_plugin(LinkAllPlugin)
